@@ -117,10 +117,10 @@ static void process(FILE *fid)
 
         /* To avoid breaking existing tests, we read what is a possible t    */
         /* component of the input and rewind the s-pointer so that the final */
-        /* output has consistent behaviour, with or without t values.        */
+        /* output has consistent behavior, with or without t values.        */
         /* This is a bit of a hack, in most cases 4D coordinates will be     */
         /* written to STDOUT (except when using -E) but the output format    */
-        /* speficied with -f is not respected for the t component, rather it */
+        /* specified with -f is not respected for the t component, rather it */
         /* is forward verbatim from the input.                               */
         char *before_time = s;
         double t = strtod(s, &s);
@@ -217,6 +217,7 @@ static void process(FILE *fid)
             printf("%s", s);
         else
             printf("\n");
+        fflush(stdout);
     }
 }
 
@@ -416,11 +417,18 @@ int main(int argc, char **argv) {
                             (void)printf("%9s %-16s %-16s %s\n", le->id,
                                          le->major, le->ell, le->name);
                     } else if (arg[1] == 'u') { /* list units */
-                        const struct PJ_UNITS *lu;
-
-                        for (lu = proj_list_units(); lu->id; ++lu)
-                            (void)printf("%12s %-20s %s\n", lu->id,
-                                         lu->to_meter, lu->name);
+                        auto units = proj_get_units_from_database(nullptr, nullptr, "linear", false, nullptr);
+                        for( int i = 0; units && units[i]; i++ )
+                        {
+                            if( units[i]->proj_short_name )
+                            {
+                                (void)printf("%12s %-20.15g %s\n",
+                                                units[i]->proj_short_name,
+                                                units[i]->conv_factor,
+                                                units[i]->name);
+                            }
+                        }
+                        proj_unit_list_destroy(units);
                     } else if (arg[1] == 'm') { /* list prime meridians */
                         const struct PJ_PRIME_MERIDIANS *lpm;
 
