@@ -286,9 +286,7 @@ int opt_input_loop (OPTARGS *opt, int binary) {
         return 1;
 
     /* ignore non-existing files - go on! */
-    if (nullptr==opt->input)
-        return opt_input_loop (opt, binary);
-    return 0;
+    return opt_input_loop (opt, binary);
 }
 
 
@@ -526,6 +524,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                 c = opt_ordinal (o, crepr);
                 if (0==c) {
                     fprintf (stderr, "Invalid option \"%s\"\n", crepr);
+                    free (o);
                     return nullptr;
                 }
 
@@ -534,6 +533,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                     *equals = '=';
                     if (opt_is_flag (o, c)) {
                         fprintf (stderr, "Option \"%s\" takes no arguments\n", crepr);
+                        free (o);
                         return nullptr;
                     }
                     o->optarg[c] = equals + 1;
@@ -544,6 +544,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                 if (!opt_is_flag (o, c)) {
                     if ((argc==i + 1) || ('+'==argv[i+1][0]) || ('-'==argv[i+1][0])) {
                         fprintf (stderr, "Missing argument for option \"%s\"\n", crepr);
+                        free (o);
                         return nullptr;
                     }
                     o->optarg[c] = argv[i + 1];
@@ -553,6 +554,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
 
                 if (!opt_is_flag (o, c)) {
                     fprintf (stderr, "Expected flag style long option here, but got \"%s\"\n", crepr);
+                    free (o);
                     return nullptr;
                 }
 
@@ -564,6 +566,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
             /* classic short options */
             if (nullptr==o->optarg[c]) {
                 fprintf (stderr, "Invalid option \"%s\"\n", crepr);
+                free (o);
                 return nullptr;
             }
 
@@ -580,6 +583,7 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                 if ((argc==i + 1) || ('+'==argv[i+1][0]) || ('-'==argv[i+1][0]))
                 {
                     fprintf (stderr, "Bad or missing arg for option \"%s\"\n", crepr);
+                    free (o);
                     return nullptr;
                 }
                 o->optarg[(int) c] = argv[i + 1];
