@@ -1627,10 +1627,7 @@ static void *pj_open_file_with_manager(projCtx ctx, const char *name,
 
 static NS_PROJ::io::DatabaseContextPtr getDBcontext(PJ_CONTEXT *ctx) {
     try {
-        if (ctx->cpp_context == nullptr) {
-            ctx->cpp_context = new projCppContext(ctx);
-        }
-        return ctx->cpp_context->getDatabaseContext().as_nullable();
+        return ctx->get_cpp_context()->getDatabaseContext().as_nullable();
     } catch (const std::exception &e) {
         pj_log(ctx, PJ_LOG_DEBUG, "%s", e.what());
         return nullptr;
@@ -1988,3 +1985,33 @@ void pj_set_searchpath(int count, const char **path) {
     proj_context_set_search_paths(nullptr, count,
                                   const_cast<const char *const *>(path));
 }
+
+/************************************************************************/
+/*                  proj_context_set_ca_bundle_path()                   */
+/************************************************************************/
+
+/** \brief Sets CA Bundle path.
+ *
+ * Those CA Bundle path will be used by PROJ when curl and PROJ_NETWORK
+ * are enabled.
+ *
+ * If set on the default context, they will be inherited by contexts created
+ * later.
+ *
+ * The path should be encoded in UTF-8.
+ *
+ * @param ctx PROJ context, or NULL for the default context.
+ * @param path Path. May be NULL.
+ *
+ * @since PROJ 7.2
+ */
+void proj_context_set_ca_bundle_path(PJ_CONTEXT *ctx, const char *path) {
+    if (!ctx)
+        ctx = pj_get_default_ctx();
+    if (!ctx)
+        return;
+    try {
+        ctx->set_ca_bundle_path(path != nullptr ? path : "");
+    } catch (const std::exception &) {
+    }
+}
