@@ -1,7 +1,7 @@
 /******************************************************************************
  *
  * Project:  PROJ
- * Purpose:  ISO19111:2018 implementation
+ * Purpose:  ISO19111:2019 implementation
  * Author:   Even Rouault <even dot rouault at spatialys dot com>
  *
  ******************************************************************************
@@ -686,12 +686,14 @@ IComparable::~IComparable() = default;
 
 /** \brief Returns whether an object is equivalent to another one.
  * @param other other object to compare to
- * @param criterion comparaison criterion.
+ * @param criterion comparison criterion.
+ * @param dbContext Database context, or nullptr.
  * @return true if objects are equivalent.
  */
-bool IComparable::isEquivalentTo(const IComparable *other,
-                                 Criterion criterion) const {
-    return _isEquivalentTo(other, criterion);
+bool IComparable::isEquivalentTo(
+    const IComparable *other, Criterion criterion,
+    const io::DatabaseContextPtr &dbContext) const {
+    return _isEquivalentTo(other, criterion, dbContext);
 }
 
 // ---------------------------------------------------------------------------
