@@ -5,6 +5,9 @@ static const char PJ_LIST_H_ID[] = "@(#)pj_list.h	4.5	95/08/09	GIE	REL";
 **
 ** Copy this file and retain only appropriate lines for subset list
 */
+PROJ_HEAD(adams_hemi, "Adams Hemisphere in a Square")
+PROJ_HEAD(adams_ws1, "Adams World in a Square I")
+PROJ_HEAD(adams_ws2, "Adams World in a Square II")
 PROJ_HEAD(aea, "Albers Equal Area")
 PROJ_HEAD(aeqd, "Azimuthal Equidistant")
 PROJ_HEAD(affine, "Affine transformation")
@@ -27,8 +30,10 @@ PROJ_HEAD(ccon, "Central Conic")
 PROJ_HEAD(cea, "Equal Area Cylindrical")
 PROJ_HEAD(chamb, "Chamberlin Trimetric")
 PROJ_HEAD(collg, "Collignon")
+PROJ_HEAD(col_urban, "Colombia Urban")
 PROJ_HEAD(comill, "Compact Miller")
 PROJ_HEAD(crast, "Craster Parabolic (Putnins P4)")
+PROJ_HEAD(defmodel, "Deformation model")
 PROJ_HEAD(deformation, "Kinematic grid shift")
 PROJ_HEAD(denoy, "Denoyer Semi-Elliptical")
 PROJ_HEAD(eck1, "Eckert I")
@@ -56,6 +61,7 @@ PROJ_HEAD(gnom, "Gnomonic")
 PROJ_HEAD(goode, "Goode Homolosine")
 PROJ_HEAD(gs48, "Mod. Stererographics of 48 U.S.")
 PROJ_HEAD(gs50, "Mod. Stererographics of 50 U.S.")
+PROJ_HEAD(guyou, "Guyou")
 PROJ_HEAD(hammer, "Hammer & Eckert-Greifendorff")
 PROJ_HEAD(hatano, "Hatano Asymmetrical Equal Area")
 PROJ_HEAD(healpix, "HEALPix")
@@ -64,6 +70,7 @@ PROJ_HEAD(helmert,   "3- and 7-parameter Helmert shift")
 PROJ_HEAD(hgridshift, "Horizontal grid shift")
 PROJ_HEAD(horner,    "Horner polynomial evaluation")
 PROJ_HEAD(igh,  "Interrupted Goode Homolosine")
+PROJ_HEAD(igh_o,  "Interrupted Goode Homolosine Oceanic View")
 PROJ_HEAD(imw_p, "International Map of the World Polyconic")
 PROJ_HEAD(isea, "Icosahedral Snyder Equal Area")
 PROJ_HEAD(kav5, "Kavraisky V")
@@ -115,6 +122,7 @@ PROJ_HEAD(ortel, "Ortelius Oval")
 PROJ_HEAD(ortho, "Orthographic")
 PROJ_HEAD(pconic, "Perspective Conic")
 PROJ_HEAD(patterson, "Patterson Cylindrical")
+PROJ_HEAD(peirce_q, "Peirce Quincuncial")
 PROJ_HEAD(pipeline, "Transformation pipeline manager")
 PROJ_HEAD(poly, "Polyconic (American)")
 PROJ_HEAD(pop, "Retrieve coordinate value from pipeline stack")
@@ -143,6 +151,7 @@ PROJ_HEAD(gstmerc, "Gauss-Schreiber Transverse Mercator (aka Gauss-Laborde Reuni
 PROJ_HEAD(tcc, "Transverse Central Cylindrical")
 PROJ_HEAD(tcea, "Transverse Cylindrical Equal Area")
 PROJ_HEAD(times, "Times Projection")
+PROJ_HEAD(tinshift, "Triangulation based transformation")
 PROJ_HEAD(tissot, "Tissot Conic")
 PROJ_HEAD(tmerc, "Transverse Mercator")
 PROJ_HEAD(tobmerc, "Tobler-Mercator")
