@@ -1,7 +1,7 @@
 /******************************************************************************
  *
  * Project:  PROJ
- * Purpose:  Test ISO19111:2018 implementation
+ * Purpose:  Test ISO19111:2019 implementation
  * Author:   Even Rouault <even dot rouault at spatialys dot com>
  *
  ******************************************************************************
@@ -44,7 +44,8 @@ namespace {
 struct UnrelatedObject : public IComparable {
     UnrelatedObject() = default;
 
-    bool _isEquivalentTo(const IComparable *, Criterion) const override {
+    bool _isEquivalentTo(const IComparable *, Criterion,
+                         const DatabaseContextPtr &) const override {
         assert(false);
         return false;
     }
@@ -205,6 +206,42 @@ TEST(datum, prime_meridian_to_PROJString) {
 
 // ---------------------------------------------------------------------------
 
+TEST(datum, prime_meridian_to_JSON) {
+
+    EXPECT_EQ(PrimeMeridian::GREENWICH->exportToJSON(
+                  &(JSONFormatter::create()->setSchema(""))),
+              "{\n"
+              "  \"type\": \"PrimeMeridian\",\n"
+              "  \"name\": \"Greenwich\",\n"
+              "  \"longitude\": 0,\n"
+              "  \"id\": {\n"
+              "    \"authority\": \"EPSG\",\n"
+              "    \"code\": 8901\n"
+              "  }\n"
+              "}");
+
+    EXPECT_EQ(PrimeMeridian::PARIS->exportToJSON(
+                  &(JSONFormatter::create()->setSchema(""))),
+              "{\n"
+              "  \"type\": \"PrimeMeridian\",\n"
+              "  \"name\": \"Paris\",\n"
+              "  \"longitude\": {\n"
+              "    \"value\": 2.5969213,\n"
+              "    \"unit\": {\n"
+              "      \"type\": \"AngularUnit\",\n"
+              "      \"name\": \"grad\",\n"
+              "      \"conversion_factor\": 0.015707963267949\n"
+              "    }\n"
+              "  },\n"
+              "  \"id\": {\n"
+              "    \"authority\": \"EPSG\",\n"
+              "    \"code\": 8903\n"
+              "  }\n"
+              "}");
+}
+
+// ---------------------------------------------------------------------------
+
 TEST(datum, datum_with_ANCHOR) {
     auto datum = GeodeticReferenceFrame::create(
         PropertyMap().set(IdentifiedObject::NAME_KEY, "WGS_1984 with anchor"),
@@ -237,7 +274,7 @@ TEST(datum, dynamic_geodetic_reference_frame) {
 
     EXPECT_EQ(drf->exportToWKT(WKTFormatter::create().get()), expected);
 
-    auto expected_wtk2_2018 =
+    auto expected_wtk2_2019 =
         "DYNAMIC[\n"
         "    FRAMEEPOCH[2018.5],\n"
         "    MODEL[\"My model\"]],\n"
@@ -248,8 +285,8 @@ TEST(datum, dynamic_geodetic_reference_frame) {
         "    ANCHOR[\"My anchor\"]]";
     EXPECT_EQ(
         drf->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
-        expected_wtk2_2018);
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
+        expected_wtk2_2019);
 }
 
 // ---------------------------------------------------------------------------
@@ -319,7 +356,7 @@ TEST(datum, temporal_datum_time_origin_non_ISO8601) {
 
 // ---------------------------------------------------------------------------
 
-TEST(datum, temporal_datum_WKT2_2018) {
+TEST(datum, temporal_datum_WKT2_2019) {
     auto datum = TemporalDatum::create(
         PropertyMap().set(IdentifiedObject::NAME_KEY, "Gregorian calendar"),
         DateTime::create("0000-01-01"),
@@ -331,7 +368,7 @@ TEST(datum, temporal_datum_WKT2_2018) {
 
     EXPECT_EQ(
         datum->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         expected);
 }
 
@@ -349,15 +386,15 @@ TEST(datum, dynamic_vertical_reference_frame) {
 
     EXPECT_EQ(drf->exportToWKT(WKTFormatter::create().get()), expected);
 
-    auto expected_wtk2_2018 = "DYNAMIC[\n"
+    auto expected_wtk2_2019 = "DYNAMIC[\n"
                               "    FRAMEEPOCH[2018.5],\n"
                               "    MODEL[\"My model\"]],\n"
                               "VDATUM[\"test\",\n"
                               "    ANCHOR[\"My anchor\"]]";
     EXPECT_EQ(
         drf->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
-        expected_wtk2_2018);
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
+        expected_wtk2_2019);
 }
 
 // ---------------------------------------------------------------------------
@@ -372,11 +409,10 @@ TEST(datum, datum_ensemble) {
         PositionalAccuracy::create("100"));
     EXPECT_EQ(ensemble->datums().size(), 2U);
     EXPECT_EQ(ensemble->positionalAccuracy()->value(), "100");
-    EXPECT_THROW(ensemble->exportToWKT(WKTFormatter::create().get()),
-                 FormattingException);
+
     EXPECT_EQ(
         ensemble->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         "ENSEMBLE[\"test\",\n"
         "    MEMBER[\"World Geodetic System 1984\",\n"
         "        ID[\"EPSG\",6326]],\n"
@@ -385,6 +421,14 @@ TEST(datum, datum_ensemble) {
         "        LENGTHUNIT[\"metre\",1],\n"
         "        ID[\"EPSG\",7030]],\n"
         "    ENSEMBLEACCURACY[100]]");
+
+    EXPECT_EQ(
+        ensemble->exportToWKT(
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2015).get()),
+        "DATUM[\"test\",\n"
+        "    ELLIPSOID[\"WGS 84\",6378137,298.257223563,\n"
+        "        LENGTHUNIT[\"metre\",1],\n"
+        "        ID[\"EPSG\",7030]]]");
 }
 
 // ---------------------------------------------------------------------------
@@ -400,7 +444,7 @@ TEST(datum, datum_ensemble_vertical) {
         PositionalAccuracy::create("100"));
     EXPECT_EQ(
         ensemble->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         "ENSEMBLE[\"unnamed\",\n"
         "    MEMBER[\"vdatum1\"],\n"
         "    MEMBER[\"vdatum2\"],\n"
